@@ -23,7 +23,7 @@
 #include <QFile>
 #include <QDateTime>
 
-QFile Log("/var/log/uRemote.log");
+QFile Log("/var/log/uremote.log");
 
 QByteArray CensorHashes(QString msg){
 	static QRegExp hashExp("[0-9A-F]{40,40}"); //matches a 40 char hex string
